==> fluxbox_1.3.5.orig.tar.gz: fluxbox-1.3.5/nls/zh_CN/generated-BIG5.m <==
$ codeset=BIG5

$set 1 #Align

1 U~
2 U
3 kU
4 
5 a
6 U
7 ~
8 W
9 i
10 ak
11 kU
12 k~
13 kW
14 W~
15 W
16 W
17 

$set 2 #BaseDisplay

1 hX... sY\n
2 \n
3 %s:      H %d\n

$set 3 #Common

1 Alpha
2 
3 
4 
5 
6 
7 	l
8 	
9 	a
10 	
11 	
12 qtm
13 T
14 
15 Fluxbox
16 ̤j
17 GITת
18 i
19 DwIC\nҤFAQC

$set 4 #Configmenu

1 
2 ۴
3 
4 EJ
5 f
6 u@
7 Focus Window on Workspace Change
8 EJҦ
9 EJsf
10 ̤j
11 
12 ܵfe
14 EJ
15 u@^
16 z
17 Alpha
18 z
19 EJfAlpha
20 DEJfAlpha
21 
22 m_
23 ~m
24 EJ
25 EJ

$set 5 #Ewmh

1 PR: s,kEWMH client listts

$set 6 #FbTkError

1 ĵiI Height > 3200 Am Height = 3200
2 ĵiI Width > 3200 Am Width = 3200
3 ĵi: [Φr^
4 tC
5 عMgX
6 kXImage
7 
8 ĵiGkalpha즳Į榡C
9 ĵiGalphaC
10 ĵiGalphaMgC
11 d̹榡(%d)
12 s
13 sAktblue bufferC
14 sAktgreen bufferC
15 sAktred bufferC
16 Dإ
17 Ҧ
18 mq

$set 7 #Fluxbox

1 ĪrcW!
2 [
3 [u
4 Retrying with
5 ĵiIk̹fI
6 k %s 
7 kݭn̹C\n̫OLf޲zbC
8 kѪR
9 PRIfluxboxu঳@ҡC
10 kX serverC\n̫OAFluxboxeFXC
11 ĵiGX serverlocale
12 ĵiGkmlocale modifiers

$set 8 #Gnome

1 : s, kGNOME client listts

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 tm
2 Fluxboxq
3 hX
4 
5 ...
6 _...
7 m
8 s[tm
9 Fluxbox
10 ĵiG[encoding]

$set 11 #Remember

1 
2 ؤo
3 ܤu@
4 
5 ...
6 m
7 Os
8 _
9 ߦ
10 
11 u@
12 

$set 12 #Screen

1 BScreen::BScreen: X server.\n t~@f޲z,display
2 W: %4d x H: %4d
3 BScreen::BScreen: ̹ %d ϥιҦ 0x%lx, m` %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clients
2 U
3 W
4 SlitV
5 Slit
6 Slit_
7 Slitm
8 Slit
9 OsSlitC

$set 14 #Toolbar

1 RWeu@
2 Ҧ
3 Ҧf
4 Ҧ̤pƪf
5 
6 eu@Ҧf
7 eu@Ҧ̤pƪf
8 u㦸
9 u_
10 um
11 u
12 uצʤ
13 G24p榡
14 G12p榡
15 ܮ榡
16 
17 Ҧ̤pƪf
18 eu@Ҧ̤pƪf

$set 15 #Window

1 RW

$set 16 #Windowmenu

1 
2 ̤p
3 
4 C
5 ̤j
6 
7 e...
8 _
9 ߦ
10 

$set 17 #Workspace

1 u@ %d
2 u@
3 sؤu@
4 ̦Z@u@

$set 18 #fbsetroot

1 : w: -solid, -mod, -gradient T@.\n
2 kpixmap atomsAI
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    ܧUH\n

$set 19 #main

1 : '-display'ݭn@
2 Bad Alloc
3 Bad cast
4 WXܭS
5 
6 ҥ~
7 
8 : '-log'ݭn@
9 Ӥ
10 Ө
11 : '-rc'ݭn@
12 : '-screen'ݭn@
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
D: http://www.fluxbox.org/\n\n\
-display <string>\t\twdisplayC\n\
-screen <all|int,int,int>\tbSw̹WܡC\n\
-rc <string>\t\t\tϥΫwC\n\
-version\t\t\tܪMZhXC\n\
-info\t\t\t\tܤ@ǦΪHC\n\
-log <filename>\t\t\tX󤤡C\n\
-help\t\t\t\tܧUHMZhXC\n\n
14 ĵi: kmҶq'DISPLAY'

$set 20

1 bDockW
2 
3 ୱ
4 Dock
5 q
6

==> fluxbox_1.3.7.orig.tar.gz: fluxbox-1.3.7/nls/zh_CN/generated-BIG5.m <==
$ codeset=BIG5

$set 1 #Align

1 U~
2 U
3 kU
4 
5 a
6 U
7 ~
8 W
9 i
10 ak
11 kU
12 k~
13 kW
14 W~
15 W
16 W
17 

$set 2 #BaseDisplay

1 hX... sY\n
2 \n
3 %s:      H %d\n

$set 3 #Common

1 Alpha
2 
3 
4 
5 
6 
7 	l
8 	
9 	a
10 	
11 	
12 qtm
13 T
14 
15 Fluxbox
16 ̤j
17 GITת
18 i
19 DwIC\nҤFAQC

$set 4 #Configmenu

1 
2 ۴
3 
4 EJ
5 f
6 u@
7 Focus Window on Workspace Change
8 EJҦ
9 EJsf
10 ̤j
11 
12 ܵfe
14 EJ
15 u@^
16 z
17 Alpha
18 z
19 EJfAlpha
20 DEJfAlpha
21 
22 m_
23 ~m
24 EJ
25 EJ

$set 5 #Ewmh

1 PR: s,kEWMH client listts

$set 6 #FbTkError

1 ĵiI Height > 3200 Am Height = 3200
2 ĵiI Width > 3200 Am Width = 3200
3 ĵi: [Φr^
4 tC
5 عMgX
6 kXImage
7 
8 ĵiGkalpha즳Į榡C
9 ĵiGalphaC
10 ĵiGalphaMgC
11 d̹榡(%d)
12 s
13 sAktblue bufferC
14 sAktgreen bufferC
15 sAktred bufferC
16 Dإ
17 Ҧ
18 mq

$set 7 #Fluxbox

1 ĪrcW!
2 [
3 [u
4 Retrying with
5 ĵiIk̹fI
6 k %s 
7 kݭn̹C\n̫OLf޲zbC
8 kѪR
9 PRIfluxboxu঳@ҡC
10 kX serverC\n̫OAFluxboxeFXC
11 ĵiGX serverlocale
12 ĵiGkmlocale modifiers

$set 8 #Gnome

1 : s, kGNOME client listts

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 tm
2 Fluxboxq
3 hX
4 
5 ...
6 _...
7 m
8 s[tm
9 Fluxbox
10 ĵiG[encoding]

$set 11 #Remember

1 
2 ؤo
3 ܤu@
4 
5 ...
6 m
7 Os
8 _
9 ߦ
10 
11 u@
12 

$set 12 #Screen

1 BScreen::BScreen: X server.\n t~@f޲z,display
2 W: %4d x H: %4d
3 BScreen::BScreen: ̹ %d ϥιҦ 0x%lx, m` %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clients
2 U
3 W
4 SlitV
5 Slit
6 Slit_
7 Slitm
8 Slit
9 OsSlitC

$set 14 #Toolbar

1 RWeu@
2 Ҧ
3 Ҧf
4 Ҧ̤pƪf
5 
6 eu@Ҧf
7 eu@Ҧ̤pƪf
8 u㦸
9 u_
10 um
11 u
12 uצʤ
13 G24p榡
14 G12p榡
15 ܮ榡
16 
17 Ҧ̤pƪf
18 eu@Ҧ̤pƪf

$set 15 #Window

1 RW

$set 16 #Windowmenu

1 
2 ̤p
3 
4 C
5 ̤j
6 
7 e...
8 _
9 ߦ
10 

$set 17 #Workspace

1 u@ %d
2 u@
3 sؤu@
4 ̦Z@u@

$set 18 #fbsetroot

1 : w: -solid, -mod, -gradient T@.\n
2 kpixmap atomsAI
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    ܧUH\n

$set 19 #main

1 : '-display'ݭn@
2 Bad Alloc
3 Bad cast
4 WXܭS
5 
6 ҥ~
7 
8 : '-log'ݭn@
9 Ӥ
10 Ө
11 : '-rc'ݭn@
12 : '-screen'ݭn@
13 Fluxbox %s: (c) %s Fluxbox Team\n\
D: http://www.fluxbox.org/\n\n\
-display <string>\t\twdisplayC\n\
-screen <all|int,int,int>\tbSw̹WܡC\n\
-no-slit\t\t\tdo not provide a slit.\n\
-no-toolbar\t\t\tdo not provide a toolbar.\n\
-rc <string>\t\t\tϥΫwC\n\
-version\t\t\tܪMZhXC\n\
-info\t\t\t\tܤ@ǦΪHC\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\tX󤤡C\n\
-help\t\t\t\tܧUHMZhXC\n\n
14 ĵi: kmҶq'DISPLAY'

$set 20

1 bDockW
2 
3 ୱ
4 Dock
5 q
6
